@@ -20,14 +20,13 @@ use Twig\Node\CheckToStringNode;
 use Twig\Node\Expression\AbstractExpression;
 use Twig\Node\Expression\ConstantExpression;
 use Twig\Node\Expression\FilterExpression;
-use Twig\Node\Expression\NameExpression;
-use Twig\Node\Expression\TempNameExpression;
+use Twig\Node\Expression\Variable\ContextVariable;
+use Twig\Node\Expression\Variable\LocalVariable;
 use Twig\Node\Node;
 use Twig\Node\PrintNode;
 use Twig\Node\TextNode;
 
 use function array_merge;
-use function class_exists;
 use function count;
 use function sprintf;
 use function str_replace;
@@ -43,41 +42,34 @@ class TransNode extends Node
 {
     /**
      * The label for gettext notes to be exported
-     *
-     * @var string
      */
-    public static $notesLabel = '// notes: ';
+    public static string $notesLabel = '// notes: ';
 
     /**
      * Enable MoTranslator functions
-     *
-     * @var bool
      */
-    public static $enableMoTranslator = false;
+    public static bool $enableMoTranslator = false;
 
     /**
      * Enable calls to addDebugInfo
-     *
-     * @var bool
      */
-    public static $enableAddDebugInfo = false;
+    public static bool $enableAddDebugInfo = false;
 
     /**
      * Enables context functions usage
-     *
-     * @var bool
      */
-    public static $hasContextFunctions = false;
+    public static bool $hasContextFunctions = false;
 
+    /** @phpstan-ignore constructor.unusedParameter */
     public function __construct(
         Node $body,
-        ?Node $plural,
-        ?AbstractExpression $count,
-        ?Node $context = null,
-        ?Node $notes = null,
-        ?Node $domain = null,
+        Node|null $plural,
+        AbstractExpression|null $count,
+        Node|null $context = null,
+        Node|null $notes = null,
+        Node|null $domain = null,
         int $lineno = 0,
-        ?string $tag = null
+        string|null $tag = null,
     ) {
         $nodes = ['body' => $body];
         if ($count !== null) {
@@ -100,7 +92,7 @@ class TransNode extends Node
             $nodes['context'] = $context;
         }
 
-        parent::__construct($nodes, [], $lineno, $tag);
+        parent::__construct($nodes, [], $lineno);
     }
 
     /**
@@ -130,14 +122,13 @@ class TransNode extends Node
         if ($this->hasNode('notes')) {
             $message = trim($this->getNode('notes')->getAttribute('data'));
 
-            // line breaks are not allowed cause we want a single line comment
+            // line breaks are not allowed because we want a single line comment
             $message = str_replace(["\n", "\r"], ' ', $message);
             $compiler->raw(static::$notesLabel . $message . "\n");
         }
 
         if ($vars) {
-            $compiler
-                ->raw($this->echoOrYield() . ' strtr(' . $function . '(');
+            $compiler->raw('yield strtr(' . $function . '(');
 
             if ($hasDomain) {
                 [$domain] = $this->compileString($this->getNode('domain'));
@@ -186,8 +177,7 @@ class TransNode extends Node
 
             $compiler->raw("));\n");
         } else {
-            $compiler
-                ->raw($this->echoOrYield() . ' ' . $function . '(');
+            $compiler->raw('yield ' . $function . '(');
 
             if ($hasDomain) {
                 [$domain] = $this->compileString($this->getNode('domain'));
@@ -223,14 +213,12 @@ class TransNode extends Node
 
     /**
      * Keep this method protected instead of private some implementations may use it
+     *
+     * @psalm-return array{Node, list<ContextVariable>}
      */
     protected function compileString(Node $body): array
     {
-        if (
-            $body instanceof NameExpression
-            || $body instanceof ConstantExpression
-            || $body instanceof TempNameExpression
-        ) {
+        if ($body instanceof ContextVariable || $body instanceof ConstantExpression || $body instanceof LocalVariable) {
             return [$body, []];
         }
 
@@ -251,7 +239,7 @@ class TransNode extends Node
 
                     $attributeName = $n->getAttribute('name');
                     $msg .= sprintf('%%%s%%', $attributeName);
-                    $vars[] = new NameExpression($attributeName, $n->getTemplateLine());
+                    $vars[] = new ContextVariable($attributeName, $n->getTemplateLine());
                 } else {
                     /** @phpstan-var TextNode $node */
                     $msg .= $node->getAttribute('data');
@@ -261,7 +249,7 @@ class TransNode extends Node
             $msg = $body->getAttribute('data');
         }
 
-        return [new Node([new ConstantExpression(trim($msg), $body->getTemplateLine())]), $vars];
+        return [new I18nNode(new ConstantExpression(trim($msg), $body->getTemplateLine()), [], 0), $vars];
     }
 
     /**
@@ -317,9 +305,4 @@ class TransNode extends Node
         // gettext($msgid);
         return $functionPrefix . ($hasContext ? 'pgettext' : 'gettext');
     }
-
-    private function echoOrYield(): string
-    {
-        return class_exists(YieldReady::class) ? 'yield' : 'echo';
-    }
 }
