@@ -15,24 +15,17 @@ declare(strict_types=1);
 namespace PhpMyAdmin\Tests\Twig\Extensions\Node;
 
 use PhpMyAdmin\Twig\Extensions\Node\TransNode;
-use Twig\Attribute\YieldReady;
 use Twig\Node\Expression\ConstantExpression;
-use Twig\Node\Expression\NameExpression;
-use Twig\Node\Node;
+use Twig\Node\Expression\Variable\ContextVariable;
+use Twig\Node\Nodes;
 use Twig\Node\PrintNode;
 use Twig\Node\TextNode;
 use Twig\Test\NodeTestCase;
 
-use function class_exists;
 use function sprintf;
 
 class MoTranslatorTransTest extends NodeTestCase
 {
-    private function echoOrYield(): string
-    {
-        return class_exists(YieldReady::class) ? 'yield' : 'echo';
-    }
-
     public static function setUpBeforeClass(): void
     {
         TransNode::$notesLabel = '// l10n: ';
@@ -48,25 +41,25 @@ class MoTranslatorTransTest extends NodeTestCase
     public function testFullConstructor(): void
     {
         $count = new ConstantExpression(12, 0);
-        $body = new Node([
+        $body = new Nodes([
             new TextNode('Hello', 0),
-        ], [], 0);
-        $notes = new Node([
+        ]);
+        $notes = new Nodes([
             new TextNode('notes for translators', 0),
-        ], [], 0);
-        $domain = new Node([
+        ]);
+        $domain = new Nodes([
             new TextNode('mydomain', 0),
-        ], [], 0);
-        $context = new Node([
+        ]);
+        $context = new Nodes([
             new TextNode('mydomain', 0),
-        ], [], 0);
-        $plural = new Node([
+        ]);
+        $plural = new Nodes([
             new TextNode('Hey ', 0),
-            new PrintNode(new NameExpression('name', 0), 0),
+            new PrintNode(new ContextVariable('name', 0), 0),
             new TextNode(', I have ', 0),
-            new PrintNode(new NameExpression('count', 0), 0),
+            new PrintNode(new ContextVariable('count', 0), 0),
             new TextNode(' apples', 0),
-        ], [], 0);
+        ]);
         $node = new TransNode($body, $plural, $count, $context, $notes, $domain, 0);
 
         $this->assertEquals($body, $node->getNode('body'));
@@ -77,175 +70,169 @@ class MoTranslatorTransTest extends NodeTestCase
         $this->assertEquals($context, $node->getNode('context'));
     }
 
-    /**
-     * @return array[]
-     */
+    /** @return mixed[] */
     public function getTests(): array
     {
         $tests = [];
 
-        $body = new NameExpression('foo', 0);
-        $domain = new Node([
+        $body = new ContextVariable('foo', 0);
+        $domain = new Nodes([
             new TextNode('coredomain', 0),
-        ], [], 0);
+        ]);
         $node = new TransNode($body, null, null, null, null, $domain, 0);
         $tests[] = [
             $node,
-            sprintf($this->echoOrYield() . ' _dgettext("coredomain", %s);', $this->getVariableGetter('foo')),
+            sprintf('yield _dgettext("coredomain", %s);', $this->getVariableGetter('foo')),
         ];
 
-        $body = new NameExpression('foo', 0);
-        $domain = new Node([
+        $body = new ContextVariable('foo', 0);
+        $domain = new Nodes([
             new TextNode('coredomain', 0),
-        ], [], 0);
-        $context = new Node([
+        ]);
+        $context = new Nodes([
             new TextNode('The context', 0),
-        ], [], 0);
+        ]);
         $node = new TransNode($body, null, null, $context, null, $domain, 0);
         $tests[] = [
             $node,
             sprintf(
-                $this->echoOrYield() . ' _dpgettext("coredomain", "The context", %s);',
-                $this->getVariableGetter('foo')
+                'yield _dpgettext("coredomain", "The context", %s);',
+                $this->getVariableGetter('foo'),
             ),
         ];
 
-        $body = new Node([
+        $body = new Nodes([
             new TextNode('J\'ai ', 0),
-            new PrintNode(new NameExpression('foo', 0), 0),
+            new PrintNode(new ContextVariable('foo', 0), 0),
             new TextNode(' pommes', 0),
-        ], [], 0);
+        ]);
         $node = new TransNode($body, null, null, null, null, null, 0);
         $tests[] = [
             $node,
             sprintf(
-                $this->echoOrYield() . ' strtr(_gettext("J\'ai %%foo%% pommes"), array("%%foo%%" => %s, ));',
-                $this->getVariableGetter('foo')
+                'yield strtr(_gettext("J\'ai %%foo%% pommes"), array("%%foo%%" => %s, ));',
+                $this->getVariableGetter('foo'),
             ),
         ];
 
         $count = new ConstantExpression(12, 0);
-        $body = new Node([
+        $body = new Nodes([
             new TextNode('Hey ', 0),
-            new PrintNode(new NameExpression('name', 0), 0),
+            new PrintNode(new ContextVariable('name', 0), 0),
             new TextNode(', I have one apple', 0),
-        ], [], 0);
-        $plural = new Node([
+        ]);
+        $plural = new Nodes([
             new TextNode('Hey ', 0),
-            new PrintNode(new NameExpression('name', 0), 0),
+            new PrintNode(new ContextVariable('name', 0), 0),
             new TextNode(', I have ', 0),
-            new PrintNode(new NameExpression('count', 0), 0),
+            new PrintNode(new ContextVariable('count', 0), 0),
             new TextNode(' apples', 0),
-        ], [], 0);
+        ]);
         $node = new TransNode($body, $plural, $count, null, null, null, 0);
         $tests[] = [
             $node,
             sprintf(
-                $this->echoOrYield() . ' strtr(_ngettext("Hey %%name%%, I have one apple", "Hey %%name%%,'
+                'yield strtr(_ngettext("Hey %%name%%, I have one apple", "Hey %%name%%,'
                 . ' I have %%count%% apples", abs(12)), array("%%name%%" => %s,'
                 . ' "%%name%%" => %s, "%%count%%" => abs(12), ));',
                 $this->getVariableGetter('name'),
-                $this->getVariableGetter('name')
+                $this->getVariableGetter('name'),
             ),
         ];
 
-        $body = new Node([
+        $body = new Nodes([
             new TextNode('J\'ai ', 0),
-            new PrintNode(new NameExpression('foo', 0), 0),
+            new PrintNode(new ContextVariable('foo', 0), 0),
             new TextNode(' pommes', 0),
-        ], [], 0);
-        $context = new Node([
+        ]);
+        $context = new Nodes([
             new TextNode('The context', 0),
-        ], [], 0);
+        ]);
         $node = new TransNode($body, null, null, $context, null, null, 0);
         $tests[] = [
             $node,
             sprintf(
-                $this->echoOrYield()
-                . ' strtr(_pgettext("The context", "J\'ai %%foo%% pommes"), array("%%foo%%" => %s, ));',
-                $this->getVariableGetter('foo')
+                'yield strtr(_pgettext("The context", "J\'ai %%foo%% pommes"), array("%%foo%%" => %s, ));',
+                $this->getVariableGetter('foo'),
             ),
         ];
 
         $count = new ConstantExpression(12, 0);
-        $body = new Node([
+        $body = new Nodes([
             new TextNode('Hey ', 0),
-            new PrintNode(new NameExpression('name', 0), 0),
+            new PrintNode(new ContextVariable('name', 0), 0),
             new TextNode(', I have one apple', 0),
-        ], [], 0);
-        $context = new Node([
+        ]);
+        $context = new Nodes([
             new TextNode('The context', 0),
-        ], [], 0);
-        $plural = new Node([
+        ]);
+        $plural = new Nodes([
             new TextNode('Hey ', 0),
-            new PrintNode(new NameExpression('name', 0), 0),
+            new PrintNode(new ContextVariable('name', 0), 0),
             new TextNode(', I have ', 0),
-            new PrintNode(new NameExpression('count', 0), 0),
+            new PrintNode(new ContextVariable('count', 0), 0),
             new TextNode(' apples', 0),
-        ], [], 0);
+        ]);
         $node = new TransNode($body, $plural, $count, $context, null, null, 0);
         $tests[] = [
             $node,
             sprintf(
-                $this->echoOrYield()
-                . ' strtr(_npgettext("The context", "Hey %%name%%, I have one apple", "Hey %%name%%,'
+                'yield strtr(_npgettext("The context", "Hey %%name%%, I have one apple", "Hey %%name%%,'
                 . ' I have %%count%% apples", abs(12)), array("%%name%%" => %s,'
                 . ' "%%name%%" => %s, "%%count%%" => abs(12), ));',
                 $this->getVariableGetter('name'),
-                $this->getVariableGetter('name')
+                $this->getVariableGetter('name'),
             ),
         ];
 
-        $body = new Node([
+        $body = new Nodes([
             new TextNode('J\'ai ', 0),
-            new PrintNode(new NameExpression('foo', 0), 0),
+            new PrintNode(new ContextVariable('foo', 0), 0),
             new TextNode(' pommes', 0),
-        ], [], 0);
-        $context = new Node([
+        ]);
+        $context = new Nodes([
             new TextNode('The context', 0),
-        ], [], 0);
-        $domain = new Node([
+        ]);
+        $domain = new Nodes([
             new TextNode('mydomain', 0),
-        ], [], 0);
+        ]);
         $node = new TransNode($body, null, null, $context, null, $domain, 0);
         $tests[] = [
             $node,
             sprintf(
-                $this->echoOrYield()
-                . ' strtr(_dpgettext("mydomain", "The context", "J\'ai %%foo%% pommes"), array("%%foo%%" => %s, ));',
-                $this->getVariableGetter('foo')
+                'yield strtr(_dpgettext("mydomain", "The context", "J\'ai %%foo%% pommes"), array("%%foo%%" => %s, ));',
+                $this->getVariableGetter('foo'),
             ),
         ];
 
         $count = new ConstantExpression(12, 0);
-        $body = new Node([
+        $body = new Nodes([
             new TextNode('Hey ', 0),
-            new PrintNode(new NameExpression('name', 0), 0),
+            new PrintNode(new ContextVariable('name', 0), 0),
             new TextNode(', I have one apple', 0),
-        ], [], 0);
-        $context = new Node([
+        ]);
+        $context = new Nodes([
             new TextNode('The context', 0),
-        ], [], 0);
-        $domain = new Node([
+        ]);
+        $domain = new Nodes([
             new TextNode('mydomain', 0),
-        ], [], 0);
-        $plural = new Node([
+        ]);
+        $plural = new Nodes([
             new TextNode('Hey ', 0),
-            new PrintNode(new NameExpression('name', 0), 0),
+            new PrintNode(new ContextVariable('name', 0), 0),
             new TextNode(', I have ', 0),
-            new PrintNode(new NameExpression('count', 0), 0),
+            new PrintNode(new ContextVariable('count', 0), 0),
             new TextNode(' apples', 0),
-        ], [], 0);
+        ]);
         $node = new TransNode($body, $plural, $count, $context, null, $domain, 0);
         $tests[] = [
             $node,
             sprintf(
-                $this->echoOrYield()
-                . ' strtr(_dnpgettext("mydomain", "The context", "Hey %%name%%, I have one apple",'
+                'yield strtr(_dnpgettext("mydomain", "The context", "Hey %%name%%, I have one apple",'
                 . ' "Hey %%name%%, I have %%count%% apples", abs(12)), array("%%name%%" => %s,'
                 . ' "%%name%%" => %s, "%%count%%" => abs(12), ));',
                 $this->getVariableGetter('name'),
-                $this->getVariableGetter('name')
+                $this->getVariableGetter('name'),
             ),
         ];
 
